@@ -2,7 +2,7 @@
 #define MAVLINK_TYPES_H_
 
 // Visual Studio versions before 2013 don't conform to C99.
-#if (defined _MSC_VER) & (_MSC_VER < 1800)
+#if (defined _MSC_VER) && (_MSC_VER < 1800)
 #include <stdint.h>
 #else
 #include <inttypes.h>
@@ -23,7 +23,7 @@
 #define MAVLINK_MSG_ID_EXTENDED_MESSAGE 255
 #define MAVLINK_EXTENDED_HEADER_LEN 14
 
-#if (defined _MSC_VER) | ((defined __APPLE__) & (defined __MACH__)) | (defined __linux__)
+#if (defined _MSC_VER) || ((defined __APPLE__) && (defined __MACH__)) || (defined __linux__)
   /* full fledged 32bit++ OS */
   #define MAVLINK_MAX_EXTENDED_PACKET_LEN 65507
 #else
@@ -36,6 +36,8 @@
 #pragma pack(push, 1)
 
 /**
+ * Old-style 4 byte param union
+ *
  * This struct is the data format to be used when sending
  * parameters. The parameter should be copied to the native
  * type (without type conversion)
@@ -56,17 +58,50 @@ typedef struct param_union {
 	uint8_t type;
 } mavlink_param_union_t;
 
+
+/**
+ * New-style 8 byte param union
+ * mavlink_param_union_double_t will be 8 bytes long, and treated as needing 8 byte alignment for the purposes of MAVLink 1.0 field ordering.
+ * The mavlink_param_union_double_t will be treated as a little-endian structure.
+ *
+ * If is_double is 1 then the type is a double, and the remaining 63 bits are the double, with the lowest bit of the mantissa zero.
+ * The intention is that by replacing the is_double bit with 0 the type can be directly used as a double (as the is_double bit corresponds to the
+ * lowest mantissa bit of a double). If is_double is 0 then mavlink_type gives the type in the union.
+ * The mavlink_types.h header will also need to have shifts/masks to define the bit boundaries in the above,
+ * as bitfield ordering isn’t consistent between platforms. The above is intended to be for gcc on x86,
+ * which should be the same as gcc on little-endian arm. When using shifts/masks the value will be treated as a 64 bit unsigned number,
+ * and the bits pulled out using the shifts/masks.
+*/
+typedef union {
+    struct {
+        uint8_t is_double:1;
+        uint8_t mavlink_type:7;
+        union {
+            char c;
+            uint8_t uint8;
+            int8_t int8;
+            uint16_t uint16;
+            int16_t int16;
+            uint32_t uint32;
+            int32_t int32;
+            float f;
+            uint8_t align[7];
+        };
+    };
+    uint8_t data[8];
+} mavlink_param_union_double_t;
+
+/**
+ * This structure is required to make the mavlink_send_xxx convenience functions
+ * work, as it tells the library what the current system and component ID are.
+ */
 typedef struct __mavlink_system {
     uint8_t sysid;   ///< Used by the MAVLink message_xx_send() convenience function
     uint8_t compid;  ///< Used by the MAVLink message_xx_send() convenience function
-    uint8_t type;    ///< Unused, can be used by user to store the system's type
-    uint8_t state;   ///< Unused, can be used by user to store the system's state
-    uint8_t mode;    ///< Unused, can be used by user to store the system's mode
-    uint32_t nav_mode;    ///< Unused, can be used by user to store the system's navigation mode
 } mavlink_system_t;
 
 typedef struct __mavlink_message {
-	uint16_t checksum; /// sent at end of packet
+	uint16_t checksum; ///< sent at end of packet
 	uint8_t magic;   ///< protocol magic marker
 	uint8_t len;     ///< Length of payload
 	uint8_t seq;     ///< Sequence of packet
