@@ -142,6 +142,7 @@ class mavfile(object):
         self.mav_loss = 0
         self.mav_count = 0
         self.stop_on_EOF = False
+        self.portdead = False
 
     def auto_mavlink_version(self, buf):
         '''auto-switch mavlink protocol version'''
@@ -688,6 +689,8 @@ class mavserial(mavfile):
     '''a serial mavlink port'''
     def __init__(self, device, baud=115200, autoreconnect=False, source_system=255):
         import serial
+        if ',' in device and not os.path.exists(device):
+            device, baud = device.split(',')
         self.baud = baud
         self.device = device
         self.autoreconnect = autoreconnect
@@ -733,27 +736,31 @@ class mavserial(mavfile):
         try:
             return self.port.write(buf)
         except Exception:
+            if not self.portdead:
+                print("Device %s is dead" % self.device)
+            self.portdead = True
             if self.autoreconnect:
                 self.reset()
             return -1
             
     def reset(self):
         import serial
-        self.port.close()
-        while True:
+        try:
+            newport = serial.Serial(self.device, self.baud, timeout=0,
+                                    dsrdtr=False, rtscts=False, xonxoff=False)
+            self.port.close()
+            self.port = newport
+            print("Device %s reopened OK" % self.device)
+            self.portdead = False
             try:
-                self.port = serial.Serial(self.device, self.baud, timeout=0,
-                                          dsrdtr=False, rtscts=False, xonxoff=False)
-                try:
-                    self.fd = self.port.fileno()
-                except Exception:
-                    self.fd = None
-                if self.rtscts:
-                    self.set_rtscts(self.rtscts)
-                return
+                self.fd = self.port.fileno()
             except Exception:
-                print("Failed to reopen %s" % self.device)
-                time.sleep(0.5)
+                self.fd = None
+            if self.rtscts:
+                self.set_rtscts(self.rtscts)
+            return True
+        except Exception:
+            return False
         
 
 class mavudp(mavfile):
@@ -838,7 +845,7 @@ class mavtcp(mavfile):
         self.port.setblocking(0)
         set_close_on_exec(self.port.fileno())
         self.port.setsockopt(socket.SOL_TCP, socket.TCP_NODELAY, 1)
-        mavfile.__init__(self, self.port.fileno(), device, source_system=source_system)
+        mavfile.__init__(self, self.port.fileno(), "tcp:" + device, source_system=source_system)
 
     def close(self):
         self.port.close()
@@ -994,6 +1001,11 @@ def mavlink_connection(device, baud=115200, source_system=255,
         set_dialect(dialect)
     if device.startswith('tcp:'):
         return mavtcp(device[4:], source_system=source_system)
+    if device.startswith('udpin:'):
+        return mavudp(device[6:], input=True, source_system=source_system)
+    if device.startswith('udpout:'):
+        return mavudp(device[7:], input=False, source_system=source_system)
+    # For legacy purposes we accept the following syntax and let the caller to specify direction
     if device.startswith('udp:'):
         return mavudp(device[4:], input=input, source_system=source_system)
 
