@@ -9,45 +9,42 @@ header. The timestamp is in microseconds since 1970 (unix epoch)
 
 import sys, time, os, struct, json
 
-from optparse import OptionParser
-parser = OptionParser("mavlogdump.py [options] <LOGFILE>")
+from argparse import ArgumentParser
+parser = ArgumentParser(description=__doc__)
 
-parser.add_option("--no-timestamps",dest="notimestamps", action='store_true', help="Log doesn't have timestamps")
-parser.add_option("--planner",dest="planner", action='store_true', help="use planner file format")
-parser.add_option("--robust",dest="robust", action='store_true', help="Enable robust parsing (skip over bad data)")
-parser.add_option("-f", "--follow",dest="follow", action='store_true', help="keep waiting for more data at end of file")
-parser.add_option("--condition",dest="condition", default=None, help="select packets by condition")
-parser.add_option("-q", "--quiet", dest="quiet", action='store_true', help="don't display packets")
-parser.add_option("-o", "--output", default=None, help="output matching packets to give file")
-parser.add_option("-p", "--parms",  action='store_true', help="preserve parameters in output with -o")
-parser.add_option("--format", dest="format", default=None, help="Change the output format between 'standard', 'json', and 'csv'. For the CSV output, you must supply types that you want.")
-parser.add_option("--csv_sep", dest="csv_sep", default=",", help="Select the delimiter between columns for the output CSV file. Use 'tab' to specify tabs. Only applies when --format=csv")
-parser.add_option("--types",  default=None, help="types of messages (comma separated)")
-parser.add_option("--dialect",  default="ardupilotmega", help="MAVLink dialect")
-parser.add_option("--zero-time-base",  action='store_true', help="use Z time base for DF logs")
-(opts, args) = parser.parse_args()
+parser.add_argument("--no-timestamps", dest="notimestamps", action='store_true', help="Log doesn't have timestamps")
+parser.add_argument("--planner", action='store_true', help="use planner file format")
+parser.add_argument("--robust", action='store_true', help="Enable robust parsing (skip over bad data)")
+parser.add_argument("-f", "--follow", action='store_true', help="keep waiting for more data at end of file")
+parser.add_argument("--condition", default=None, help="select packets by condition")
+parser.add_argument("-q", "--quiet", action='store_true', help="don't display packets")
+parser.add_argument("-o", "--output", default=None, help="output matching packets to give file")
+parser.add_argument("-p", "--parms", action='store_true', help="preserve parameters in output with -o")
+parser.add_argument("--format", default=None, help="Change the output format between 'standard', 'json', and 'csv'. For the CSV output, you must supply types that you want.")
+parser.add_argument("--csv_sep", dest="csv_sep", default=",", help="Select the delimiter between columns for the output CSV file. Use 'tab' to specify tabs. Only applies when --format=csv")
+parser.add_argument("--types", default=None, help="types of messages (comma separated)")
+parser.add_argument("--dialect", default="ardupilotmega", help="MAVLink dialect")
+parser.add_argument("--zero-time-base", action='store_true', help="use Z time base for DF logs")
+parser.add_argument("log", metavar="LOG")
+args = parser.parse_args()
 
 import inspect
 
 from pymavlink import mavutil
 
 
-if len(args) < 1:
-    parser.print_help()
-    sys.exit(1)
-
-filename = args[0]
-mlog = mavutil.mavlink_connection(filename, planner_format=opts.planner,
-                                  notimestamps=opts.notimestamps,
-                                  robust_parsing=opts.robust,
-                                  dialect=opts.dialect,
-                                  zero_time_base=opts.zero_time_base)
+filename = args.log
+mlog = mavutil.mavlink_connection(filename, planner_format=args.planner,
+                                  notimestamps=args.notimestamps,
+                                  robust_parsing=args.robust,
+                                  dialect=args.dialect,
+                                  zero_time_base=args.zero_time_base)
 
 output = None
-if opts.output:
-    output = open(opts.output, mode='wb')
+if args.output:
+    output = open(args.output, mode='wb')
 
-types = opts.types
+types = args.types
 if types is not None:
     types = types.split(',')
 
@@ -55,13 +52,13 @@ ext = os.path.splitext(filename)[1]
 isbin = ext in ['.bin', '.BIN']
 islog = ext in ['.log', '.LOG']
 
-if opts.csv_sep == "tab":
-    opts.csv_sep = "\t"
+if args.csv_sep == "tab":
+    args.csv_sep = "\t"
 
 # Write out a header row as we're outputting in CSV format.
 fields = ['timestamp']
 offsets = {}
-if opts.format == 'csv':
+if args.format == 'csv':
     try:
         currentOffset = 1 # Store how many fields in we are for each message.
         for type in types:
@@ -75,7 +72,7 @@ if opts.format == 'csv':
     except TypeError:
         print("You must specify a list of message types if outputting CSV format via the --types argument.")
         exit()
-    
+
     # The first line output are names for all columns
     print(','.join(fields))
 
@@ -84,8 +81,9 @@ last_timestamp = None
 
 # Keep track of data from the current timestep. If the following timestep has the same data, it's stored in here as well. Output should therefore have entirely unique timesteps.
 csv_out = ["" for x in fields]
+types_ignored = set() # Track which message types were ignored
 while True:
-    m = mlog.recv_match(blocking=opts.follow)
+    m = mlog.recv_match(blocking=args.follow)
     if m is None:
         # FIXME: Make sure to output the last CSV message before dropping out of this loop
         break
@@ -93,17 +91,22 @@ while True:
         if (isbin or islog) and m.get_type() == "FMT":
             output.write(m.get_msgbuf())
             continue
-        if (isbin or islog) and (m.get_type() == "PARM" and opts.parms):
+        if (isbin or islog) and (m.get_type() == "PARM" and args.parms):
             output.write(m.get_msgbuf())
             continue
-        if m.get_type() == 'PARAM_VALUE' and opts.parms:
+        if m.get_type() == 'PARAM_VALUE' and args.parms:
             timestamp = getattr(m, '_timestamp', None)
             output.write(struct.pack('>Q', timestamp*1.0e6) + m.get_msgbuf())
             continue
-    if not mavutil.evaluate_condition(opts.condition, mlog.messages):
+    if not mavutil.evaluate_condition(args.condition, mlog.messages):
         continue
 
     if types is not None and m.get_type() not in types and m.get_type() != 'BAD_DATA':
+        # If this message hasn't been seen before, and it's not being output, issue a warning.
+        # This makes it easy for a developer to confirm that they're extracting all relevant data.
+        if m.get_type() not in types_ignored:
+            sys.stderr.write("WARNING: Ignoring '{}' message types.\n".format(m.get_type()))
+            types_ignored.add(m.get_type())
         continue
 
     if m.get_type() == 'BAD_DATA' and m.reason == "Bad prefix":
@@ -119,36 +122,36 @@ while True:
         output.write(m.get_msgbuf())
 
     # If quiet is specified, don't display output to the terminal.
-    if opts.quiet:
+    if args.quiet:
         continue
 
     # If JSON was ordered, serve it up. Split it nicely into metadata and data.
-    if opts.format == 'json':
+    if args.format == 'json':
         # Format our message as a Python dict, which gets us almost to proper JSON format
         data = m.to_dict()
-        
+
         # Remove the mavpackettype value as we specify that later.
         del data['mavpackettype']
-        
+
         # Also, if it's a BAD_DATA message, make it JSON-compatible by removing array objects
         if 'data' in data and type(data['data']) is not dict:
             data['data'] = list(data['data'])
-        
+
         # Prepare the message as a single object with 'meta' and 'data' keys holding
         # the message's metadata and actual data respectively.
         outMsg = {"meta": {"msgId": m.get_msgId(), "type": m.get_type(), "timestamp": m._timestamp}, "data": data}
-        
+
         # Now print out this object with stringified properly.
         print(json.dumps(outMsg))
     # CSV format outputs columnar data with a user-specified delimiter
-    elif opts.format == 'csv':
+    elif args.format == 'csv':
         data = m.to_dict()
         type = m.get_type()
 
         # If this message has a duplicate timestamp, copy its data into the existing data list. Also
         # do this if it's the first message encountered.
         if timestamp == last_timestamp or last_timestamp is None:
-            newData = [str(data[y.split('.')[-1]]) if y.split('.')[0] == type and y.split('.')[-1] in data else "" for y in [type + '.' + x for x in fields]]
+            newData = [str(data[y.split('.')[-1]]) if y.split('.')[0] == type and y.split('.')[-1] in data else "" for y in fields]
             for i, val in enumerate(newData):
                 if val:
                     csv_out[i] = val
@@ -156,8 +159,8 @@ while True:
         # Otherwise if this is a new timestamp, print out the old output data, and store the current message for later output.
         else:
             csv_out[0] = "{:.8f}".format(last_timestamp)
-            print(opts.csv_sep.join(csv_out))
-            csv_out = [str(data[y.split('.')[-1]]) if y.split('.')[0] == type and y.split('.')[-1] in data else "" for y in [type + '.' + x for x in fields]]
+            print(args.csv_sep.join(csv_out))
+            csv_out = [str(data[y.split('.')[-1]]) if y.split('.')[0] == type and y.split('.')[-1] in data else "" for y in fields]
     # Otherwise we output in a standard Python dict-style format
     else:
         print("%s.%02u: %s" % (
